%%
%% This is file `octave/massplot.m',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% adjust.dtx  (with options: `massplot')
%% 
%% -------------------------------------------------------------------------
%% Logarithmic binning histogram adjustment.
%% 
%% J. Alex Stark, National Institute of Statistical Sciences, NC.
%% Copyright 1997-9, all rights reserved.  See source file for disclaimer.
%% -------------------------------------------------------------------------
function massplot(SScaleT)
%  function massplot(SScaleT)
% 
%  This function demonstrates problems with histograms of logarithmic
%  durations and presents some solutions.
% 
%  Troublesome SScaleT values include 19.385 and 40.25
% 
%  For COPYRIGHT information, see the accompanying documentation.
if exist('OCTAVE_VERSION')
  InMatlab=0;
else
  InMatlab=1;
end

format compact

errorplot = (1==1);

if nargin<1
  if errorplot
    SScaleT=40.25;
  else
    SScaleT=19.385;
  end
end
tmean = 70;
tau=tmean;
r=1-1/tau;
tmax=1000;

xmax=floor(SScaleT*log10(tmax));   % number of log bins -1
ixdiv=10;

tres = 10;
u=([1/tres:1/tres:tmax]'-0.5/tres)/tmax;
t = -tmean*log(u);
ft=t*0+1/tres/tmax;  % same length as t, all entries the same

x = (0:xmax)/SScaleT;
ix=(0:1/ixdiv:xmax)/SScaleT;
xsel=1:ixdiv:length(ix);

ifhist = ix-log10(tmean);
                                % Generates ideal pdf for base10 logs
ifhist = log(10)*10.^(ifhist-10.^ifhist/log(10));
tmp = round(t);

fhist = hist(round(SScaleT*log10(tmp(tmp>0))),(0:xmax)-0.1)/tres/tmax;

ex=10.^(x);
eix=10.^(ix);
if InMatlab
  figure(1)
end
plot(ex,fhist*SScaleT,'o',eix,ifhist,'b-')

prntmass(1,'fluct')
if InMatlab
  figure(2)
end
plot([ex(1)*10.^(-1/2/SScaleT) ex(floor(1:0.5:xmax+1))*10.^(1/2/SScaleT)],...
    fhist(floor(1:0.5:xmax+1.5))*SScaleT)

prntmass(2,'ftrad')
[a,b,Weight,l,h]=dismass(SScaleT,fhist,'e');

if InMatlab
  figure(3)
end
plot(b,a,'o',eix,ifhist,'b-')

prntmass(3,'adjpt')
NWeight = Weight*SScaleT;

if errorplot
  if InMatlab
    figure(4)
  end

  DegFac = (10.^(1/2/SScaleT)-10.^(-1/2/SScaleT));
  fprintf(2,'Ignore any warnings: positive errors in red.\n');
  plot(b,((1./NWeight(NWeight>0)-1)),'ro', ...
      b,(-(1./NWeight(NWeight>0)-1)),'bo',...
      b,(1./(b*DegFac)),'m-',...
      b,(1./(b*DegFac-1)*(DegFac*DegFac+2)/2),'r-',...
      b,(1./(b*DegFac+1)),'b-')

  prntmass(-4,'error1')
  if InMatlab
    figure(5)
  end

  plot(b,(NWeight(NWeight>0)-1),'bo', ...
      b,(1-NWeight(NWeight>0)),'ro',...
      b,(1./b/DegFac),'b-',...
      b,(1./(2*b*DegFac+DegFac*DegFac)*(DegFac*DegFac+2)),'r-')

  prntmass(-5,'error2')

end
[a,b,Weight,l,h]=dismass(SScaleT,fhist,'m');

nmass = length(b);
hx=[l h]';
hx=hx(:);
hy=[a a]';
hy=hy(:);

if InMatlab
  figure(4)
end
plot(hx,hy,'r-',eix,ifhist,'b-')

prntmass(4,'adjtrad')
[a,b,Weight,l,h]=dismass(SScaleT,fhist,'e',1);

nmass = length(b);
hx=[l h]';
hx=hx(:);
hy=[a a]';
hy=hy(:);

if InMatlab
  figure(5)
end
plot(hx,hy,'r-',eix,ifhist,'b-')

prntmass(5,'adjehist')
[a,b,Weight,l,h]=dismass(SScaleT,fhist,'s',1);

nmass = length(b);
hx=[l h]';
hx=hx(:);
hy=[a a]';
hy=hy(:);

if InMatlab
figure(6)
end
plot(hx,hy,'r-',eix,ifhist,'b-' )

prntmass(6,'adjhist')
rand('seed',7);
dfhist = zeros(xmax+1,1);

tau=[70 4];
qq=0.35;  % amount of dist in component 2
Nrands = 3000;

t = -tau(1+(rand(Nrands,1)<qq))' .* log(rand(Nrands,1));

tmp = round(t);
ft=t*0+1/Nrands;

dfhist = hist(round(SScaleT*log10(tmp(tmp>0))),(0:xmax)-0.1)/Nrands;

ifhistA = ix-log10(tau(1));
ifhistB = ix-log10(tau(2));
ifhist = log(10)*qq*10.^(ifhistB-10.^(ifhistB)/log(10)) + ...
    log(10)*(1-qq)*10.^(ifhistA-10.^(ifhistA)/log(10));

[a,b,Weight]=dismass(SScaleT,dfhist);
if InMatlab
  figure(7)
plot(ex,dfhist*SScaleT,'o', ...
    b,a,'.',  ...
    eix,ifhist,'-')
ch=get(gca,'children');
set(ch(2),'markersize',14);
else
plot(ex,dfhist*SScaleT,'o', ...
    b,a,'mx',  ...
    eix,ifhist,'-')
end
prntmass(7,'dblt')
%% 
%%  End of file.
%% 
%%
%% End of file `octave/massplot.m'.
